@@ -221,7 +221,7 @@ def _PyScript(env, target, source, command = "python $SOURCES",
     command = [ env.subst(c, target=target, source=subst) for c in command ]
     return env.Command(target, source, command, *args, **kwargs) 
 
-def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = True, tempdir = None):
+def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options="", clean = True, tempdir = None):
     target = ToList(target) 
     source = ToList(source) 
 
@@ -249,10 +249,9 @@ def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = T
         env.Execute(cleancmd)
         env.Execute(Delete(TEMP))
 
-    if clean: 
-        cmd = [Mkdir(TEMP), cmd, clean, Delete(TEMP)]
-    else:
-        cmd = [Mkdir(TEMP), cmd]
+    if not execute: cmd = [Mkdir(TEMP), cmd]
+    else: cmd = [execute + " " + tempdir]
+    if clean: cmd += [Delete(TEMP)]
 
     gen = lambda source, target, env, for_signature: sig if for_signature else cmd 
     return env.Command(target, source + [scons], CommandGeneratorAction(gen,{}))
@@ -321,8 +320,8 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
 
     env.Default(targets)
 
-
-    env.Command(out, targets + [os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
+    SIGNATURES = os.path.join(basename, ".sconsign.dblite")
+    env.Command(out, targets, "tar cjf $TARGET $SOURCES")
 
     return targets, sources, basename
 
